@@ -1,22 +1,24 @@
 import copy
 import os
 import re
+import shutil
 import tempfile
 from collections import defaultdict
 from contextlib import contextmanager
-from pathlib import Path
 
 import click
 
 from indico_install.cluster_manager import ClusterManager
 from indico_install.config import (
+    CLUSTER_NAME,
+    D_PATH,
     REMOTE_TEMPLATES_PATH,
+    SERVICES_YAML,
     ConfigsLoader,
     merge_dicts,
     yaml,
 )
-from indico_install.setup import setup
-from indico_install.utils import options_wrapper, run_cmd, string_to_tag
+from indico_install.utils import run_cmd
 
 var_regex = re.compile(r"<\!var:([^<>]*)>")
 lookup_regex = re.compile(r"<\!lookup:([^<>]*)>")
@@ -75,7 +77,6 @@ def _resolve_template(template_values, variables, conf):
 
 
 def helm_render(
-    deployment_root,
     templates_dir,
     group,
     template,
@@ -83,7 +84,7 @@ def helm_render(
     values_files="",
     enabled_resource_validation=True,
 ):
-    generated_dir = deployment_root / "generated"
+    generated_dir = D_PATH / "generated"
     click.echo(f"Generating {values['name']}.yaml")
     with _resolve_values(values) as resolved_str:
         results = run_cmd(
@@ -207,20 +208,16 @@ def format_resources(helm_info, warn=True):
     return helm_info
 
 
-def render_from_local(
-    deployment_root, templates_dir, cluster, services_yaml, input_yaml, services=None
-):
-    generated = deployment_root / "generated"
+def render_from_local(templates_dir, services_yaml, input_yaml, services=None):
+    generated = D_PATH / "generated"
     click.secho(f"clearing {generated}", fg="yellow")
     os.makedirs(generated, exist_ok=True)
     run_cmd(f"rm -rf {generated/ '*.yaml'}", silent=True)
 
-    setup(input_yaml)
     # images will be "updated" by Indico and contains cluster defaults
     # input is customer overrides
     configs = ConfigsLoader(services_yaml, input_yaml)
     resolve_all(configs)
-    resource_limits = not configs.get("disableResourceLimits", False)
 
     with _resolve_values(configs) as resolved_str:
         for resource, helm_info in configs["services"].items():
@@ -237,6 +234,11 @@ def render_from_local(
                 for k, v in helm_info.items()
                 if k not in ("group", "template", "values")
             }
+            if "disableResourceLimits" in helm_info:
+                resource_limits = not helm_info.get("disableResourceLimits")
+            else:
+                resource_limits = not configs.get("disableResourceLimits", False)
+
             helm_info["values"] = merge_dicts(extra_keys, helm_info["values"])
             [helm_info.pop(k) for k in extra_keys.keys()]
 
@@ -245,7 +247,6 @@ def render_from_local(
 
             try:
                 helm_render(
-                    deployment_root,
                     templates_dir,
                     values_files=f"{resolved_str}",
                     enabled_resource_validation=resource_limits,
@@ -254,10 +255,10 @@ def render_from_local(
             except Exception as e:
                 click.secho(f"Unable to render template for {resource}: {e}")
 
-    configs.save(deployment_root / "configuration" / f"{cluster}.yaml")
+    configs.save(D_PATH / "configuration" / f"{CLUSTER_NAME}.yaml")
 
 
-def _resolve_remote(deployment_root, remote_path):
+def _resolve_remote(remote_path):
     """
     Download remote templates and services yaml and unpack
     Unpack if necessary, and validate contents (error if validation fails)
@@ -266,9 +267,7 @@ def _resolve_remote(deployment_root, remote_path):
     remote_templates_path = REMOTE_TEMPLATES_PATH + remote_path + "/templates.tar.gz"
     remote_services_yaml = REMOTE_TEMPLATES_PATH + remote_path + "/services.yaml"
     local_directory = (
-        deployment_root
-        / "remote_configs"
-        / "".join(c for c in str(remote_path) if c.isalnum)
+        D_PATH / "remote_configs" / "".join(c for c in str(remote_path) if c.isalnum)
     )
     if not local_directory.parent.exists():
         local_directory.parent.mkdir(exist_ok=True, parents=True)
@@ -279,63 +278,51 @@ def _resolve_remote(deployment_root, remote_path):
     os.makedirs(local_directory / "templates", exist_ok=True)
 
     run_cmd(
+        f"wget {remote_services_yaml} -O {local_directory / 'services.yaml'}",
+        silent=True
+    )
+    assert (local_directory / 'services.yaml').is_file(), (
+        f"Unable to download version {remote_path}"
+    )
+    run_cmd(
         f"wget {remote_templates_path} -O - | "
-        f"tar -xz -C {local_directory / 'templates'}"
+        f"tar -xz -C {local_directory / 'templates'}",
+        silent=True
     )
-    run_cmd(f"wget {remote_services_yaml} -O {local_directory / 'services.yaml'}")
     return (local_directory / "services.yaml", local_directory / "templates")
 
 
 @click.command("render")
 @click.pass_context
 @click.argument("services", required=False, nargs=-1)
+@click.option("--local", is_flag=True, help="Use local services yaml and templates")
 @click.option(
-    "-r",
-    "--remote-configs",
-    help="Remote GCS folder with configs to render from. Ex: 'latest' or 'master.2423'",
+    "--no-clean", is_flag=True, help="Keep the remote templates directory",
 )
-@click.option("--local", is_flag=True, help="Use local services yaml for rendering")
-@options_wrapper()
 def render(
     ctx,
     services=None,
-    *,
-    deployment_root,
-    cluster,
-    input_yaml,
-    services_yaml,
-    remote_configs,
+    local=None,
+    no_clean=None,
     cluster_manager=None,
     allow_image_overrides=False,
-    local=None,
-    **kwargs,
 ):
     """
-    Render Helm templates from the "templates" directories.
+    Render remote Helm templates.
 
     Only render the template for services with names containing <SERVICE> if provided
     """
-    deployment_root = Path(deployment_root)
-    templates_dir = deployment_root / "templates"
+    templates_dir = D_PATH / "templates"
+    remote = False
 
-    cluster_manager = cluster_manager or ClusterManager(input_yaml=input_yaml)
+    cluster_manager = cluster_manager or ClusterManager()
     # Determine and download the updraft version templates
-    if remote_configs:
-        remote_configs = string_to_tag(remote_configs)
-        if cluster_manager.indico_version:
-            click.secho(
-                "Not using `indico updraft -v` for version changes!", fg="yellow"
-            )
-        else:
-            cluster_manager.indico_version = remote_configs
-        services_yaml, templates_dir = _resolve_remote(
-            deployment_root, string_to_tag(remote_configs)
-        )
-    elif cluster_manager.indico_version and not local:
-        services_yaml, templates_dir = _resolve_remote(
-            deployment_root, cluster_manager.indico_version
-        )
-    elif not local:
+    if cluster_manager.indico_version and not local:
+        services_yaml, templates_dir = _resolve_remote(cluster_manager.indico_version)
+        remote = True
+    elif local:
+        services_yaml = SERVICES_YAML
+    else:
         click.secho(
             "No render version supplied! Please use `indico updraft -v`", fg="red"
         )
@@ -359,23 +346,13 @@ def render(
         input_yaml.flush()
         try:
             render_from_local(
-                deployment_root,
-                templates_dir,
-                cluster,
-                services_yaml,
-                input_yaml.name,
-                services=services,
-            )
-            # Input yaml contains secrets that we need to include here
-            input_yaml.seek(0)
-            cluster_manager.edit_cluster_config(
-                changes=merge_dicts(
-                    yaml.safe_load(input_yaml),
-                    old_conf if allow_image_overrides else {},
-                )
+                templates_dir, services_yaml, input_yaml.name, services=services,
             )
+            cluster_manager.edit_cluster_config(changes=old_conf)
             cluster_manager.save()
         finally:
             os.remove(input_yaml.name)
 
     click.secho("Templates generated!", fg="green", bold=True)
+    if remote and not no_clean:
+        shutil.rmtree(templates_dir.parent)
